==> gromacs_2018.1.orig.tar.gz: gromacs-2018.1/src/programs/view/buttons.h <==
/*
 * This file is part of the GROMACS molecular simulation package.
 *
 * Copyright (c) 1991-2000, University of Groningen, The Netherlands.
 * Copyright (c) 2001-2004, The GROMACS development team.
 * Copyright (c) 2013, by the GROMACS development team, led by
 * Mark Abraham, David van der Spoel, Berk Hess, and Erik Lindahl,
 * and including many others, as listed in the AUTHORS file in the
 * top-level source directory and at http://www.gromacs.org.
 *
 * GROMACS is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 2.1
 * of the License, or (at your option) any later version.
 *
 * GROMACS is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with GROMACS; if not, see
 * http://www.gnu.org/licenses, or write to the Free Software Foundation,
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.
 *
 * If you want to redistribute modifications to GROMACS, please
 * consider that scientific software is very special. Version
 * control is crucial - bugs must be traceable. We will be happy to
 * consider code for inclusion in the official distribution, but
 * derived work must not be called official GROMACS. Details are found
 * in the README & COPYING files - if they are missing, get the
 * official version at http://www.gromacs.org.
 *
 * To help us fund GROMACS development, we humbly ask that you cite
 * the research papers on the package. Check out http://www.gromacs.org.
 */

#ifndef _buttons_h
#define _buttons_h

#include "xutil.h"

enum {
    IDROTX, IDROTY, IDROTZ, IDTRANSX, IDTRANSY, IDTRANSZ, IDZOOM, IDBUTNR,
    IDREWIND, IDSTEP, IDFF, IDSTOP_ANI, IDNR,
    IDDRAWMOL, IDLABEL
};

#define AIR      3            /* extra space between child windows */
#define BORDER  1

#define EnterLeave (EnterWindowMask | LeaveWindowMask)

typedef struct {
    t_windata wd;
    int       ID;
} t_mwbut;

typedef struct {
    t_windata  wd;
    int        nbut;
    t_mwbut   *b;
} t_butbox;

extern t_butbox *init_vbox(t_x11 *x11, Window Parent, Window SendTo,
                           unsigned long fg, unsigned long bg);

extern void set_vbtime(t_x11 *x11, t_butbox *vbox, char *text);

extern t_butbox *init_bbox(t_x11 *x11, Window Parent, Window SendTo,
                           int width, unsigned long fg, unsigned long bg);

extern void show_but(t_x11 *x11, t_butbox *bbox);

extern void hide_but(t_x11 *x11, t_butbox *bbox);

extern void done_bbox(t_x11 *x11, t_butbox *bbox);

#endif

==> gromacs_2020.1.orig.tar.gz: gromacs-2020.1/src/programs/view/buttons.h <==
/*
 * This file is part of the GROMACS molecular simulation package.
 *
 * Copyright (c) 1991-2000, University of Groningen, The Netherlands.
 * Copyright (c) 2001-2004, The GROMACS development team.
 * Copyright (c) 2013,2019, by the GROMACS development team, led by
 * Mark Abraham, David van der Spoel, Berk Hess, and Erik Lindahl,
 * and including many others, as listed in the AUTHORS file in the
 * top-level source directory and at http://www.gromacs.org.
 *
 * GROMACS is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 2.1
 * of the License, or (at your option) any later version.
 *
 * GROMACS is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with GROMACS; if not, see
 * http://www.gnu.org/licenses, or write to the Free Software Foundation,
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.
 *
 * If you want to redistribute modifications to GROMACS, please
 * consider that scientific software is very special. Version
 * control is crucial - bugs must be traceable. We will be happy to
 * consider code for inclusion in the official distribution, but
 * derived work must not be called official GROMACS. Details are found
 * in the README & COPYING files - if they are missing, get the
 * official version at http://www.gromacs.org.
 *
 * To help us fund GROMACS development, we humbly ask that you cite
 * the research papers on the package. Check out http://www.gromacs.org.
 */

#ifndef _buttons_h
#define _buttons_h

#include "xutil.h"

enum
{
    IDROTX,
    IDROTY,
    IDROTZ,
    IDTRANSX,
    IDTRANSY,
    IDTRANSZ,
    IDZOOM,
    IDBUTNR,
    IDREWIND,
    IDSTEP,
    IDFF,
    IDSTOP_ANI,
    IDNR,
    IDDRAWMOL,
    IDLABEL
};

#define AIR 3 /* extra space between child windows */
#define BORDER 1

#define EnterLeave (EnterWindowMask | LeaveWindowMask)

typedef struct
{
    t_windata wd;
    int       ID;
} t_mwbut;

typedef struct
{
    t_windata wd;
    int       nbut;
    t_mwbut*  b;
} t_butbox;

extern t_butbox* init_vbox(t_x11* x11, Window Parent, Window SendTo, unsigned long fg, unsigned long bg);

extern void set_vbtime(t_x11* x11, t_butbox* vbox, char* text);

extern t_butbox* init_bbox(t_x11* x11, Window Parent, Window SendTo, int width, unsigned long fg, unsigned long bg);

extern void show_but(t_x11* x11, t_butbox* bbox);

extern void hide_but(t_x11* x11, t_butbox* bbox);

extern void done_bbox(t_x11* x11, t_butbox* bbox);

#endif
